AuthenticationErrorEvent class final

Reports an authentication error.

This event is used to display error messages to the user when an authentication operation fails.

Inheritance

Constructors

AuthenticationErrorEvent({required String title, required String message, Object? error})
const

Properties

error → Object?
Optional error object for debugging
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Detailed error message for the user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Error title for display in UI
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited