LoginWithSavedLoginEvent class final

Triggers biometric authentication using saved credentials.

This uses the device's fingerprint, face recognition, or other biometric authentication method to log in with stored credentials.

Inheritance

Constructors

LoginWithSavedLoginEvent()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited