UserAuthenticatedWithMultipleTenantsState class final

State when user is authenticated but has access to multiple tenants.

The application should show a tenant selection UI to let the user choose which tenant context they want to work in.

Inheritance

Constructors

UserAuthenticatedWithMultipleTenantsState({required List<Tenant> tenants})
const

Properties

hasError → bool
Returns true if the last authentication operation resulted in an error
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAuthenticated → bool
Returns true if the user is fully authenticated with a selected tenant
no setterinherited
isLoading → bool
Returns true if an authentication operation is in progress
no setterinherited
isSelectingTenant → bool
Returns true if the user is authenticated but needs to select a tenant
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenants → List<Tenant>
List of tenants the user has access to
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited