blocs/push_notification/push_notification_bloc library

Classes

DidMountedCheckInitialMessage
Event to check for notifications that launched the app.
DidReceivedDataOnlyNotificationEvent
Event triggered when a data-only FCM message is received in the foreground.
DidReceivedNotificationEvent
Event triggered when a push notification is received in the foreground.
DidResetNotificationEvent
Event to reset notification state to initial.
DidUserOpenedDataOnlyNotificationEvent
Event triggered when user opens a data-only FCM message.
DidUserOpenedNotificationEvent
Event triggered when user taps on a notification.
NotificationData
Base notification data that is shared between different notification states
PushNotificationBloc
Manages Firebase Cloud Messaging push notifications.
PushNotificationDataOnlyOpened
Push notification opened state for data-only messages.
PushNotificationDataOnlyReceived
Push notification received state for data-only messages.
PushNotificationError
Push notification error state
PushNotificationEvent
Base class for all push notification events.
PushNotificationInitial
Push notification initial state
PushNotificationOpened
Push notification opened state
PushNotificationPayload
Contains the data payload from a Firebase Cloud Messaging notification.
PushNotificationReceived
Push notification received state
PushNotificationState
Push notification state

Extensions

RemoteMessageExtension on RemoteMessage
Extension methods for convenient access to RemoteMessage data.