DidUserOpenedDataOnlyNotificationEvent class final

Event triggered when user opens a data-only FCM message.

This is fired for RemoteMessage instances that do not contain a notification object, and only provide data payload.

Inheritance

Constructors

DidUserOpenedDataOnlyNotificationEvent({required PushNotificationPayload payload, String? linkMobile})
Creates a data-only notification opened event.

Properties

hashCode int
The hash code for this object.
no setterinherited
linkMobile String?
Optional deep link URL for mobile navigation
final
payload PushNotificationPayload
Additional notification data payload
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited