PushNotificationDataOnlyReceived class final

Push notification received state for data-only messages.

Represents a RemoteMessage that does not contain a notification object, and only provides data payload.

Inheritance

Constructors

PushNotificationDataOnlyReceived({required PushNotificationPayload payload, String? linkMobile})
Push notification received state for data-only messages
const

Properties

hashCode int
The hash code for this object.
no setterinherited
linkMobile String?
Optional deep link URL for mobile navigation
final
payload PushNotificationPayload
Parsed notification payload data
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the state to a JSON map.
override
toOpenedEvent() DidUserOpenedDataOnlyNotificationEvent
Converts to opened data-only notification event
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited