DeviceInfo class

Constructors

DeviceInfo({required String deviceName, required String deviceModel, required String operatingSystem, required String systemVersion, required String deviceUuid, required bool isPhysicalDevice})
Constructs an instance of DeviceInfo.

Properties

deviceModel → String
The model of the device.
final
deviceName → String
The name of the device.
final
deviceUuid → String
The UUID of the device (if available).
final
hashCode → int
The hash code for this object.
no setterinherited
isPhysicalDevice → bool
Whether the device is a physical device.
final
operatingSystem → String
The operating system of the device.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemVersion → String
The system version of the device.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getDeviceInfo() → Future<DeviceInfo>
Static method to gather device information for all supported platforms.