SubApp class abstract

Constructors

SubApp()

Properties

appIcon → String?
no setter
darkTheme → ThemeData
no setter
hashCode → int
The hash code for this object.
no setterinherited
homePage → String
no setter
label → String?
no setter
lightTheme → ThemeData
no setter
routePrefix → String
no setter
routes → List<RouteBase>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subsystemId → int?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited