TenantAuthentication class

A class representing the authentication information for a tenant.

This class holds the tenant and the app user information required for authentication.

Constructors

TenantAuthentication(CurrentTenant tenant, AppUser appUser)
Constructs an instance of TenantAuthentication.

Properties

appUser → AppUser
The app user associated with the authentication.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenant → CurrentTenant
The tenant associated with the authentication.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited