JsonDouble constructor

JsonDouble(
  1. String fieldName
)

Creates a new JsonDouble field with the specified field name.

The fieldName corresponds to the key in the JSON object that this field will map to during serialization and deserialization.

Parameters:

  • fieldName: The name of the field as it appears in JSON data.

Implementation

JsonDouble(super.fieldName);