AppUserInfo class

Inheritance
Mixed-in types

Constructors

AppUserInfo()

Properties

address ↔ JsonString
getter/setter pair
adminType ↔ JsonObject<AdminType>
The user's admin type as an EnumModel.
getter/setter pairinherited
adminTypeId ↔ JsonInteger
The ID of the user's admin type.
getter/setter pairinherited
appleAccount ↔ JsonString
getter/setter pairinherited
appUserAccountId ↔ JsonInteger
getter/setter pair
appUserId ↔ JsonInteger
getter/setter pair
avatarId ↔ JsonInteger
getter/setter pair
avatarUrl ↔ JsonString
getter/setter pair
birthday ↔ JsonDate
getter/setter pair
currentTenant ↔ JsonObject<CurrentTenant>
getter/setter pair
currentTenantId ↔ JsonInteger
getter/setter pair
defaultTenantId ↔ JsonInteger
getter/setter pair
defaultUrl ↔ JsonString
getter/setter pair
displayName ↔ JsonString
getter/setter pair
email ↔ JsonString
getter/setter pair
error → String?
Returns the first general error message, or null if there are no errors.
no setterinherited
errors ↔ Map<String, String?>
A map of field-specific error messages, keyed by field name.
getter/setter pairinherited
fields → List<JsonField>
The list of JSON fields that define the structure of this model.
no setteroverride
gender ↔ JsonObject<Gender>
The user's gender as an EnumModel.
getter/setter pairinherited
genderId ↔ JsonInteger
The ID of the user's gender.
getter/setter pairinherited
generalErrors ↔ List<String>
A list of general error messages that apply to the entire model.
getter/setter pairinherited
generalInformations ↔ List<String>
A list of general informational messages about the model.
getter/setter pairinherited
generalWarnings ↔ List<String>
A list of general warning messages that apply to the entire model.
getter/setter pairinherited
globalUserId ↔ JsonInteger
The global user ID.
getter/setter pair
googleAccount ↔ JsonString
getter/setter pairinherited
groupTimeZone ↔ JsonObject<Timezone>
getter/setter pairinherited
hasError → bool
Returns true if the model has any field-specific or general errors.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasInformation → bool
Returns true if the model has any field-specific or general informational messages.
no setterinherited
hasWarning → bool
Returns true if the model has any field-specific or general warnings.
no setterinherited
information → String?
Returns the first general informational message, or null if there are none.
no setterinherited
informations ↔ Map<String, String?>
A map of field-specific informational messages, keyed by field name.
getter/setter pairinherited
isAdmin ↔ JsonBoolean
getter/setter pairinherited
isAlreadyGettingStarted ↔ JsonBoolean
getter/setter pair
language ↔ JsonObject<Language>
The user's language as an EnumModel.
getter/setter pairinherited
languageId ↔ JsonInteger
The ID of the user's language.
getter/setter pairinherited
microsoftAccount ↔ JsonString
getter/setter pairinherited
phone ↔ JsonString
getter/setter pair
preferenceFields → List<JsonField>
no setterinherited
receivingSystemEmail ↔ JsonBoolean
Indicates if the user is receiving system emails.
getter/setter pairinherited
receivingSystemNotification ↔ JsonBoolean
Indicates if the user is receiving system notifications.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sites ↔ JsonList<AppUserSite>
The sites available to the user.
getter/setter pair
tenants ↔ JsonList<Tenant>
getter/setter pair
timezone ↔ JsonObject<Timezone>
The user's timezone as an EnumModel.
getter/setter pairinherited
timezoneId ↔ JsonInteger
The ID of the user's timezone.
getter/setter pairinherited
username ↔ JsonString
getter/setter pair
warning → String?
Returns the first general warning message, or null if there are no warnings.
no setterinherited
warnings ↔ Map<String, String?>
A map of field-specific warning messages, keyed by field name.
getter/setter pairinherited

Methods

fromJson(dynamic json) → void
Deserializes JSON data into this model instance.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAppUser() → AppUser
toJson() → Map<String, dynamic>
Serializes this model instance to a JSON map.
inherited
toString() → String
Returns a JSON string representation of this model.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String name) → dynamic
Retrieves the value of a field by its name using bracket notation.
inherited
operator []=(String name, dynamic value) → void
Sets the value of a field by its name using bracket notation.
inherited