obtainKey method
Returns a synchronous future containing this provider instance as the key.
This method is required by ImageProvider and is used by Flutter's image loading system to identify and cache image instances.
Implementation
@override
Future<DioImageProvider> obtainKey(ImageConfiguration configuration) {
return SynchronousFuture<DioImageProvider>(this);
}