SupaArchitecturePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SupaArchitecturePlatform
Implementers

Constructors

SupaArchitecturePlatform()
Constructs a SupaArchitecturePlatform.

Properties

cookieStorage ↔ CookieManager
latefinal
deviceInfo ↔ DeviceInfo
latefinal
hashCode → int
The hash code for this object.
no setterinherited
persistentStorage → PersistentStorage
The persistent storage service.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureStorage → SecureStorage
final
useFirebase ↔ bool
latefinal

Methods

getBaseUrl() → String
getPlatformVersion() → Future<String?>
initialize({bool useFirebase = false}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ SupaArchitecturePlatform
The default instance of SupaArchitecturePlatform to use.
getter/setter pair