height property
The height of the image widget.
If null, the image will size itself based on its intrinsic dimensions.
Implementation
final double? height;
The height of the image widget.
If null, the image will size itself based on its intrinsic dimensions.
final double? height;