onConfirm property

VoidCallback onConfirm
final

Callback function executed when the confirm button is pressed.

The dialog will automatically close after this callback is executed.

Implementation

final VoidCallback onConfirm;