DidUserOpenedNotificationEvent class final
Event triggered when user taps on a notification.
This event is fired when the user interacts with a notification (either from the system tray or as a foreground notification banner), causing the app to open or come to the foreground.
- Inheritance
-
- Object
- PushNotificationEvent
- DidUserOpenedNotificationEvent
Constructors
- DidUserOpenedNotificationEvent({required String title, required String body, required PushNotificationPayload payload, String? linkMobile})
- Creates a notification opened event with the given notification data.
Properties
- body → String
-
The notification body text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linkMobile → String?
-
Optional deep link URL for mobile navigation
final
- payload → PushNotificationPayload
-
Additional notification data payload
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - title → String
-
The notification title text
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited