fallbackAssetPath property
The path to the fallback asset image that will be used if the network request fails.
This should be a valid asset path as registered in your pubspec.yaml file.
For example: 'assets/images/placeholder.png'
Implementation
final String fallbackAssetPath;