onConfirm property
Callback function executed when the confirm button is pressed.
The dialog will automatically close after this callback is executed.
Implementation
final VoidCallback onConfirm;
Callback function executed when the confirm button is pressed.
The dialog will automatically close after this callback is executed.
final VoidCallback onConfirm;